yp_bootparam(1M)

yp_bootparam - update NIS bootparams database

As shipped in IRIX 6.5.19. Unchanged since IRIX 6.5.

NAME
     yp_bootparam - update NIS bootparams database

SYNOPSIS
     yp_bootparam -h host -a [ -b ] [ -k key_file ] -f file
     yp_bootparam -h host -a [ -b ] [ -k key_file ] params
     yp_bootparam -h host -d [ -b ] [ -k key_file ]

DESCRIPTION
     yp_bootparam is the user interface tool to update NIS bootparams(4)
     database directly on client workstation without running on ypmaster.
     yp_bootparam uses the ypupdated(1M) service on ypmaster to update the
     bootparams database.

     User can either add an entry to database, or delete an entry.  As long as
     the hostname is registered in the NIS hosts database and the bootparam
     entry does not exist, user can always add an entry to the bootparams
     database.  In this process, a security key can be requested on return.
     When deleting an entry, the same key (if there is one) must be submitted
     in the same command line.  Otherwise, the request will be rejected.  The
     update daemon on ypmaster stores the keys in /var/boot/keystore, while
     yp_bootparam saves the key in the file specified by the input parameter.


OPTIONS
     -h host   Use host as the key in bootparams database.  The host will be
               checked against NIS hosts database unless -b is specified.  If
               host is an alias, the real key found in hosts data base will be
               used instead.


     -a        To add an entry


     -d        To remove an entry.


     -b        use host as key without checking NIS hosts database.


     -k key_file
               When adding an entry, the key_file is used to save the returned
               key.  When deleting an entry, it is used to pass the original
               key.


     -f file   The file will contain the data part in the bootparam entry.  It
               should have the following format:

                    root=root_server:root_path
                    sbin=share_server:sbin_path
                    swap=root_server:swap_path
                    dump=root_server:dump_path

               The dump value is optional.

     params    If -f is not used, the boot parameters should be passed at
               command level.

EXAMPLE
     yp_bootparam -a -h bonnie -k /mykey
          root=clyde:/dl/client/bonnie sbin=clyde:/dl/share/sbin
          swap=clyde:/dl/swap/bonnie

     will create a bootparam entry in ypmaster.  The security key returned
     will be left in /mykey.

NOTE
     After using yp_bootparam, it will take a short time for the NIS
     bootparams database, as seen by the client, to reflect the change.

CAVEAT
     yp_bootparam will not communicate with non-SGI NIS masters.

FILES
     /var/yp/yp_bootparam
     /var/boot/keystore
     /usr/include/rpcsvc/ypclnt.h       Error code listing

SEE ALSO
     bootparams(4), updbootparam(1M), ypupdated(1M)